package stdlib

import (
	"io"
	"net/http"
)

// FileLocationHTTP implements FileLocationType for a remote http url (readonly)
type FileLocationHTTP struct{}

func flHTTP(err error) FileLocationErr {
	return FileLocationErr{"http", err}
}

// ReadBody returns a reader on the body
func (fls3 *FileLocationHTTP) ReadBody(location FileLocation) (io.ReadCloser, error) {
	var url string
	url, err := location.StringArg("url")
	if err != nil {
		return nil, flHTTP(err)
	}
	resp, err := http.Get(url)
	if err != nil {
		return nil, flHTTP(err)
	}
	return WrapFileLocationReadCloser("http", resp.Body), nil
}

func init() {
	if err := RegisterFileLocationType("http", &FileLocationHTTP{}); err != nil {
		panic(err)
	}
}
